@@ -20,6 +20,9 @@ DYNAMIC_LINK_URL_BASE_COMPONENT = getattr(
     'OneTimeLink'
 )
 
+if settings.FORCE_SCRIPT_NAME:
+	DYNAMIC_LINK_URL_BASE_COMPONENT = settings.FORCE_SCRIPT_NAME + '/' + DYNAMIC_LINK_URL_BASE_COMPONENT
+
 # Uploaded files base directory
 DYNAMIC_LINK_UPLOAD_TO = getattr(
     settings,
@@ -27,6 +30,13 @@ DYNAMIC_LINK_UPLOAD_TO = getattr(
     ''
 )
 
+# Setting for schema protocal
+DYNAMIC_LINK_SCHEMA_PROTO = getattr(
+    settings,
+    'DYNAMIC_LINK_SCHEMA_PROTO',
+    'http'
+)
+
 # It's here because of not violate the DRY priciple.
 TEXT_REQUEST_DOES_NOT_EXIST = _(u'This request does not exist.')
 TEXT_REQUEST_IS_EXPIRED = _(u'Sorry, this request is already expired')
